==> qcad-3.32.4.4-3-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da_DK">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation>Lodret/Horisontal</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation>Tilbage</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>Tilpasset</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>Gitter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Slut</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>På enheden</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Lodret</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Tangentielt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Center</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Midt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Krydsningspunkt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Henvisning</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation>Afstand</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>Ugyldig</translation>
    </message>
</context>
</TS>

==> qcad-3.32.5.0-1-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da_DK">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation>Lodret/Horisontal</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation>Tilbage</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>Tilpasset</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>Gitter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Endepunkt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>På objekt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Vinkelret</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Tangentielt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Center</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Midtpunkt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Skæringspunkt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Henvisning</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation>Afstand</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>Ugyldig</translation>
    </message>
</context>
</TS>
